Module: Topsy
- Defined in:
- lib/rtopsy/api.rb,
lib/rtopsy.rb,
lib/rtopsy/tag.rb,
lib/rtopsy/page.rb,
lib/rtopsy/stats.rb,
lib/rtopsy/trend.rb,
lib/rtopsy/tweet.rb,
lib/rtopsy/author.rb,
lib/rtopsy/target.rb,
lib/rtopsy/linkpost.rb,
lib/rtopsy/url_info.rb,
lib/rtopsy/search_count.rb,
lib/rtopsy/linkpost_count.rb,
lib/rtopsy/link_search_result.rb
Overview
This is the link_search_result class for the topsy library. A LinkSearchResult has the following attributes: "trackback_permalink" : "http://twitter.com/ewerickson/status/3562164195", "hits" : 38, "trackback_total" : 157, "topsy_trackback_url" : "http://topsy.com/tb/www.redstate.com/erick/2009/08/26/breaking-rumors-surface-that-leon-panetta-is-resigning/", "url" : "http://www.redstate.com/erick/2009/08/26/breaking-rumors-surface-that-leon-panetta-is-resigning/", "content" : "Panetta is rumored to have sent a resignation letter to Barack Obama today: http://bit.ly/CDMg9", "title" : "BREAKING: Rumors Surface That Leon Panetta is Resigning - Erickâs blog - RedState", "score" : 0.75521481, "highlight" : "Panetta is rumored to have sent a resignation letter to <span class="highlight-term">Barack <span class="highlight-term">Obama today: http://bit.ly/CDMg9" According to the official Topsy doc: http://code.google.com/p/otterapi/wiki/Resources?tm=6#/search
For complete documentation on the options, check out the topsy api docs. http://groups.google.com/group/rtopsy
Defined Under Namespace
Classes: API, Author, LinkSearchResult, Linkpost, LinkpostCount, Page, SearchCount, Stats, Tag, Target, Trend, Tweet, UrlInfo
Constant Summary collapse
- VERSION =
'0.0.2'